@@ -252,7 +252,6 @@ struct _PrefsCommon
 	gint ng_abbrev_len;
 
 	gboolean show_searchbar;
-	gboolean expand_thread;
 	gboolean swap_from;
 	gboolean use_addr_book;
 	gchar *date_format;
@@ -264,12 +263,16 @@ struct _PrefsCommon
 	gboolean enable_hscrollbar;
 	gboolean bold_unread;
 	gboolean next_on_delete;
-	gboolean enable_thread;
 	gboolean thread_by_subject;
 	gint thread_by_subject_max_age; /*!< Max. age of a thread which was threaded
 					 *   by subject (days) */
 	FolderSortKey default_sort_key;
 	FolderSortType default_sort_type;
+	gboolean folder_default_thread;
+	gboolean folder_default_thread_collapsed;
+	gboolean folder_default_hide_read_threads;
+	gboolean folder_default_hide_read_msgs;
+	gboolean folder_default_hide_del_msgs;
 
 	gchar *last_opened_folder;
 	gboolean goto_last_folder_on_startup;
@@ -290,6 +293,9 @@ struct _PrefsCommon
 	/* Actions */
 	GSList *actions_list;
 
+	/* Summary lock column headers */
+	gboolean summary_col_lock;
+
 	/* Summary columns visibility, position and size */
 	gboolean summary_col_visible[N_SUMMARY_COLS];
 	gint summary_col_pos[N_SUMMARY_COLS];
@@ -490,6 +496,8 @@ struct _PrefsCommon
 	gint actionsiodialog_height;
 	gint tagswin_width;
 	gint tagswin_height;
+	gint sslmanwin_width;
+	gint sslmanwin_height;
 	gint addressbookwin_width;
 	gint addressbookwin_height;
 	gint addressbookeditpersonwin_width;
